@@ -62,7 +62,7 @@ import requests
 )
 @click.option("--insecure", "-k", is_flag=True, help="Do not verify server SSL certificate.")
 @click.option("--target-branch", "-t", help="The target branch to merge onto.")
-@click.option("--commit-prefix", "-c", default="WIP", help="Prefix for the MR title i.e. WIP.")
+@click.option("--commit-prefix", "-c", default="Draft", help="Prefix for the MR title e.g. Draft.")
 @click.option("--remove-branch", "-r", is_flag=True, help="If set will remove the source branch after MR.")
 @click.option("--squash-commits", "-s", is_flag=True, help="If set will squash commits on merge.")
 @click.option("--description", "-d", type=str, help="Path to file to use as the description for the MR.")
@@ -148,11 +148,11 @@ def cli(
 
 
 def get_mr_title(commit_prefix, source_branch):
-    """Gets the title of the MR. If a prefix exists we add it to the URL. By default we add a prefix of WIP, so the
+    """Gets the title of the MR. If a prefix exists we add it to the URL. By default we add a prefix of Draft, so the
     MR doesn't get merged by accident.
 
     Args:
-        commit_prefix (str): Prefix for the MR title i.e. WIP.
+        commit_prefix (str): Prefix for the MR title e.g. Draft.
         source_branch (str): The source branch to merge into..
 
     Returns:
